@@ -7,10 +7,11 @@ from figcli.config.style.terms.term import Term
 
 class iTerm(Term):
     TERM_PROGRAM = 'iTerm.app'
-    BLUE = (52, 213, 235)
+    BLUE = (5, 156, 205)
     GREEN = (51, 222, 136)
     RED = (240, 70, 87)
-    YELLOW = (240, 240, 70)
+    YELLOW = (249, 149, 72)
+    ORANGE = (232, 149, 39)
 
     def get_colors(self) -> Color:
         return Color(
@@ -19,6 +20,7 @@ class iTerm(Term):
                 blue=iTerm.BLUE,
                 green=iTerm.GREEN,
                 red=iTerm.RED,
-                yellow=iTerm.YELLOW
+                yellow=iTerm.YELLOW,
+                orange = iTerm.ORANGE
             )
         )
